* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Automations](https://help.sap.com/docs/leanix/ea/automations)
  * Creating an Automation with a Webhook Action
